The Longaccess Python SDK - Core
================================

This is a Python SDK for interacting with the [Longaccess service][la].

Installation
------------

Download or clone the source repository, create a [virtualenv][ve] if needed, and install the SDK via `pip`. E.g.:

    pip install https://github.com/longaccess/longaccess-core/tarball/master
    
Documentation
-------------

For version information and significant changes see [docs/changes.md](docs/changes.md)


[la]: https://www.longaccess.com "the Longaccess website"
[ve]: http://www.virtualenv.org "virtualenv"
[What is Longaccess?]: https://github.com/longaccess/longaccess-docs/blob/master/what_is_longaccess.md "what is Longaccess?"
